#!/usr/bin/env python3
# -*- coding: utf-8 -*-

#
# Copyright (c) 2013 Sven Erik Knop, Perforce Software Ltd
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# 1.  Redistributions of source code must retain the above copyright
#         notice, this list of conditions and the following disclaimer.
#
# 2.  Redistributions in binary form must reproduce the above copyright
#         notice, this list of conditions and the following disclaimer in the
#         documentation and/or other materials provided with the
#         distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE
# SOFTWARE, INC. BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# User contributed content on the Perforce Public Depot is not supported by Perforce,
# although it may be supported by its author. This applies to all contributions
# even those submitted by Perforce employees.
#
# Maintainer: Sven Erik Knop, sknop@perforce.com

# Usage: formfile workspace_name port

from __future__ import print_function

import P4
import sys

DEFAULT_VIEW = [ "//depot/gta5/... //DEFAULT/gta5/... ", "//IT/... //DEFAULT/IT/..." ]

def client_default(formfile, workspace_name, port):
    # is this workspace new?

    p4 = P4.P4()
    p4.client = workspace_name
    p4.port = port
    p4.connect()

    info = p4.run_info()[0]['clientName']
    if info != "*unknown*":
        sys.exit(0)

    p4.disconnect()

    with open(formfile) as f:
        content = f.read()

    client = p4.parse_client(content)

    view = adjust_view(workspace_name)
    
    client._view = view
    client._submitoptions = client._submitoptions.replace("submitunchanged", "revertunchanged")
    
    content = p4.format_client(client)

    with open(formfile, "w") as f:
        f.write(content)

    sys.exit(0)

def adjust_view(ws):
    view = []
    for v in DEFAULT_VIEW:
        v = v.replace("DEFAULT", ws)
        view.append(v)

    return view


if __name__ == "__main__":
    if len(sys.argv) < 4:
        print("Need <formfile> and <client workspace name> and <port>", file=sys.stderr)
        sys.exit(1)
    
    client_default(sys.argv[1], sys.argv[2], sys.argv[3])

